@@ -64,10 +64,13 @@
 #'   argument to the relevant control function. In that case,
 #'   arguments to the proposal should be specified through the
 #'   \code{obs.prop.args} argument to the relevant control function.
-#' 
-#' @param offset.coef A vector of coefficients for the offset terms. \matchnames{coefficient}
+#'
+#' @param offset.coef A vector of coefficients for the offset
+#'   terms. Note that [`NaN`] elements are treated specially. See
+#'   Skipping below. \matchnames{coefficient}
+#'
 #' @param target.stats vector of "observed network statistics,"
-#' if these statistics are for some reason different than the 
+#' if these statistics are for some reason different than the
 #' actual statistics of the network on the left-hand side of
 #' \code{formula}.
 #' Equivalently, this vector is the mean-value parameter values for the
@@ -107,57 +110,65 @@
 #'   returned as a part of the fit as a elements `newnetwork` and
 #'   `newnetworks`. (See their entries in section Value below for
 #'   details.) Partial matching is supported.
-#' 
-#' @return
-#' [ergm()] returns an object of [`ergm`] that is a list
-#' consisting of the following elements:
-#' \item{coef}{The Monte Carlo maximum likelihood estimate
-#' of \eqn{\theta}, the vector of coefficients for the model
-#' parameters.}
-#' \item{sample}{The \eqn{n\times p} matrix of network statistics, 
-#' where \eqn{n} is the                               
-#' sample size and \eqn{p} is the number of network statistics specified in the
-#' model, generated by the last iteration of the MCMC-based likelihood maximization routine. These statistics are centered with respect to the observed statistics or `target.stats`, unless missing data MLE is used.}
-#' \item{sample.obs}{As \code{sample}, but for the constrained sample.}
-#' \item{iterations}{The number of Newton-Raphson iterations required
-#' before convergence.}
-#' \item{MCMCtheta}{The value of \eqn{\theta} used to produce the Markov chain
-#' Monte Carlo sample.  As long as the Markov chain mixes sufficiently
-#' well, \code{sample} is roughly a random sample from the distribution
-#' of network statistics specified by the model with the parameter equal
-#' to \code{MCMCtheta}.  If \code{estimate="MPLE"} then 
-#' \code{MCMCtheta} equals the MPLE.}
-#' \item{loglikelihood}{The approximate change in log-likelihood 
-#' in the last iteration.
-#' The value is only approximate because it is estimated based 
-#' on the MCMC random sample.}
-#' \item{gradient}{The value of the gradient vector of the approximated
-#' loglikelihood function, evaluated at the maximizer.  This vector
-#' should be very close to zero.}
-#' \item{covar}{Approximate covariance matrix for the MLE, based on the inverse
-#' Hessian of the approximated loglikelihood evaluated at the maximizer.}
-#' \item{failure}{Logical:  Did the MCMC estimation fail?}
-#' \item{network}{Network passed on the left-hand side of `formula`. If `target.stats` are passed, it is replaced by the network returned by [san()].}
-#' \item{newnetworks}{If argument `newnetwork` is `"all"`, a list of the final networks at the end of the MCMC
-#' simulation, one for each thread.}
-#' \item{newnetwork}{If argument `newnetwork` is `"one"` or `"all"`, the first (possibly only) element of \code{newnetworks}.}
-#' \item{coef.init}{The initial value of \eqn{\theta}.}
-#' \item{est.cov}{The covariance matrix of the model statistics in the final MCMC sample.}
-#' \item{coef.hist, steplen.hist, stats.hist, stats.obs.hist}{
-#' For the MCMLE method, the history of coefficients, Hummel step lengths, and average model statistics for each iteration..
-#' }
-#' \item{control}{The control list passed to the call.}
-#' \item{etamap}{The set of functions mapping the true parameter theta
-#' to the canonical parameter eta (irrelevant except in a curved exponential
-#' family model)}
-#' \item{formula}{The original [`formula`] passed to [ergm()].}
-#' \item{target.stats}{The target.stats used during estimation (passed through from the Arguments)}
-#' \item{target.esteq}{Used for curved models to preserve the target mean values of the curved terms. It is identical to target.stats for non-curved models.}
-#' \item{constraints}{Constraints used during estimation (passed through from the Arguments)}
-#' \item{reference}{The reference measure used during estimation (passed through from the Arguments)}
-#' \item{estimate}{The estimation method used (passed through from the Arguments).}
-#' \item{offset}{vector of logical telling which model parameters are to be set
-#' at a fixed value (i.e., not estimated).}
+#'
+#' @template MCMC-skipping
+#'
+#' @return [ergm()] returns an object of [`ergm`] that is a list
+#'   consisting of the following elements: \item{coef}{The Monte Carlo
+#'   maximum likelihood estimate of \eqn{\theta}, the vector of
+#'   coefficients for the model parameters.}  \item{sample}{The
+#'   \eqn{n\times p} matrix of network statistics, where \eqn{n} is
+#'   the sample size and \eqn{p} is the number of network statistics
+#'   specified in the model, generated by the last iteration of the
+#'   MCMC-based likelihood maximization routine. These statistics are
+#'   centered with respect to the observed statistics or
+#'   `target.stats`, unless missing data MLE is used.}
+#'   \item{sample.obs}{As \code{sample}, but for the constrained
+#'   sample.}  \item{iterations}{The number of Newton-Raphson
+#'   iterations required before convergence.}  \item{MCMCtheta}{The
+#'   value of \eqn{\theta} used to produce the Markov chain Monte
+#'   Carlo sample.  As long as the Markov chain mixes sufficiently
+#'   well, \code{sample} is roughly a random sample from the
+#'   distribution of network statistics specified by the model with
+#'   the parameter equal to \code{MCMCtheta}.  If
+#'   \code{estimate="MPLE"} then \code{MCMCtheta} equals the MPLE.}
+#'   \item{loglikelihood}{The approximate change in log-likelihood in
+#'   the last iteration.  The value is only approximate because it is
+#'   estimated based on the MCMC random sample.}  \item{gradient}{The
+#'   value of the gradient vector of the approximated loglikelihood
+#'   function, evaluated at the maximizer.  This vector should be very
+#'   close to zero.}  \item{covar}{Approximate covariance matrix for
+#'   the MLE, based on the inverse Hessian of the approximated
+#'   loglikelihood evaluated at the maximizer.}
+#'   \item{failure}{Logical: Did the MCMC estimation fail?}
+#'   \item{network}{Network passed on the left-hand side of
+#'   `formula`. If `target.stats` are passed, it is replaced by the
+#'   network returned by [san()].}  \item{newnetworks}{If argument
+#'   `newnetwork` is `"all"`, a list of the final networks at the end
+#'   of the MCMC simulation, one for each thread.}
+#'   \item{newnetwork}{If argument `newnetwork` is `"one"` or `"all"`,
+#'   the first (possibly only) element of \code{newnetworks}.}
+#'   \item{coef.init}{The initial value of \eqn{\theta}.}
+#'   \item{est.cov}{The covariance matrix of the model statistics in
+#'   the final MCMC sample.}  \item{coef.hist, steplen.hist,
+#'   stats.hist, stats.obs.hist}{ For the MCMLE method, the history of
+#'   coefficients, Hummel step lengths, and average model statistics
+#'   for each iteration..  } \item{control}{The control list passed to
+#'   the call.}  \item{etamap}{The set of functions mapping the true
+#'   parameter theta to the canonical parameter eta (irrelevant except
+#'   in a curved exponential family model)} \item{formula}{The
+#'   original [`formula`] passed to [ergm()].}
+#'   \item{target.stats}{The target.stats used during estimation
+#'   (passed through from the Arguments)} \item{target.esteq}{Used for
+#'   curved models to preserve the target mean values of the curved
+#'   terms. It is identical to target.stats for non-curved models.}
+#'   \item{constraints}{Constraints used during estimation (passed
+#'   through from the Arguments)} \item{reference}{The reference
+#'   measure used during estimation (passed through from the
+#'   Arguments)} \item{estimate}{The estimation method used (passed
+#'   through from the Arguments).}  \item{offset}{vector of logical
+#'   telling which model parameters are to be set at a fixed value
+#'   (i.e., not estimated).}
 #' 
 #' \item{drop}{If \code{\link[=control.ergm]{control$drop}=TRUE}, a numeric vector indicating which terms were dropped due to to extreme values of the
 #' corresponding statistics on the observed network, and how:
@@ -585,15 +596,22 @@ ergm <- function(formula, response=NULL,
   }
 
   if(verbose){
-    message("Initial parameters:")
-    message_print(control$init)
-    message("number of free parameters: ", nparam(model, canonical=FALSE, offset=FALSE))
-    message("number of fixed parameters: ", nparam(model, canonical=FALSE, offset=TRUE))
+    message("Initial parameters provided by caller:", appendLF = FALSE)
+    init <- discard(control$init, is.na)
+    if (length(init)) {
+      message("")
+      message_print(init)
+    } else message(" None.")
+    message("  number of free parameters: ", nparam(model, canonical = FALSE, offset = FALSE))
+    message("  number of fixed parameters: ", nparam(model, canonical = FALSE, offset = TRUE))
   }
 
   # Make sure any offset elements are given in control$init.
-  if(any(is.na(control$init) & model$etamap$offsettheta)) stop("The model contains offset terms whose parameter values have not been specified:", paste.and(sQuote(param_names(model)[is.na(control$init)&model$offsettheta])), ".", sep="")
-  
+  if(any(tmp <- is.NA(control$init) & model$etamap$offsettheta)) stop("The model contains offset terms whose parameter values have not been specified:", paste.and(sQuote(param_names(model)[tmp])), ".", sep="")
+
+  # Make sure any NAN elements are offsets.
+  if(any(tmp <- is.nan(control$init) & !model$etamap$offsettheta)) stop("The model contains non-offset terms whose parameter values are NAN:", paste.and(sQuote(param_names(model)[tmp])), ".", sep="")
+
   # Check if any terms are constrained to a constant and issue a warning.
   constrcheck <- ergm.checkconstraints.model(model, proposal, control$init)
   model <- constrcheck$model; control$init <- constrcheck$init
@@ -738,7 +756,7 @@ ergm.fit <- function(nw, target.stats, model, model.obs, proposal, proposal.obs,
                                 ...)
 
   ## Extract and process the initial value for the next stage:
-  init <- coef(initialfit) |> replace(is.na, 0)
+  init <- coef(initialfit) |> replace(is.NA, 0)
   names(init) <- param_names(model, FALSE)
 
   c(
@@ -748,7 +766,7 @@ ergm.fit <- function(nw, target.stats, model, model.obs, proposal, proposal.obs,
                               control=control,
                               verbose=verbose, ...),
 
-           "CD" = ergm.CD.fixed(.constrain_init(s$model, ifelse(is.na(init),0,init)),
+           "CD" = ergm.CD.fixed(.constrain_init(s$model, ifelse(is.NA(init),0,init)),
                       s, s.obs, control, verbose,...),
 
            "Stochastic-Approximation" = ergm.stocapprox(init, s, s.obs,
