@@ -1,27 +1,12 @@
-#  File R/ergm.eta.R in package ergm, part of the
-#  Statnet suite of packages for network analysis, https://statnet.org .
+#  File R/ergm.eta.R in package ergm, part of the Statnet suite of packages for
+#  network analysis, https://statnet.org .
 #
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
+#  This software is distributed under the GPL-3 license.  It is free, open
+#  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
 #  Copyright 2003-2025 Statnet Commons
 ################################################################################
-##############################################################################
-# The <ergm.eta> function calculates and returns eta, mapped from
-# theta using the etamap object created by <ergm.etamap>.
-#
-# --PARAMETERS--
-#   theta :  the curved model parameters  
-#   etamap:  the list of values that constitutes the theta-> eta mapping
-#            and is returned by <ergm.etamap>
-#
-# --RETURNED--
-#   eta:  the canonical eta parameters as mapped from theta
-#
-###############################################################################
-
-
 
 #' Operations to map curved [ergm()] parameters onto canonical parameters
 #' 
@@ -76,3 +61,29 @@
 ergm.eta <- function(theta, etamap){
   .Call("ergm_eta_wrapper", as.numeric(theta), etamap, PACKAGE="ergm")
 }
+
+#' @rdname ergm.eta
+#' @description The \code{ergm.etagrad} function caculates and returns
+#'   the gradient of eta mapped from theta using the etamap object
+#'   created by \code{ergm.etamap}. If the gradient is only intended
+#'   to be a multiplier for some vector, the more efficient
+#'   \code{ergm.etagradmult} is recommended.
+#' @return For \code{ergm.etagrad}, a matrix of the gradient of eta
+#'   with respect to theta.
+#' @export ergm.etagrad
+ergm.etagrad <- function(theta, etamap){
+  .Call("ergm_etagrad_wrapper", as.numeric(theta), etamap, PACKAGE="ergm")
+}
+
+#' @rdname ergm.eta
+#' @description The \code{ergm.etagradmult} function calculates and
+#'   returns the product of the gradient of eta with a vector `v`.
+#' @param v a vector of the same length as the vector of mapped eta
+#'   parameters
+#' @return For \code{ergm.etagradmult}, the vector that is the product
+#'   of the gradient of eta and \code{v}.
+#' @export ergm.etagradmult
+ergm.etagradmult <- function(theta, v, etamap){
+  storage.mode(v) <- "double"
+  .Call("ergm_etagradmult_wrapper", as.numeric(theta), v,  etamap, PACKAGE="ergm")
+}
