@@ -152,12 +152,12 @@ ergm.mple<-function(s, s.obs, init=NULL,
    covar <- array(0,dim=c(1,1))
    hess <- array(0,dim=c(1,1))
   }else{
-   covar <- diag(rep(0,length(theta)))
-   hess <- diag(rep(0,length(theta)))
+   covar <- diag(dbl_along(theta))
+   hess <- diag(dbl_along(theta))
   }
 
-  covar %[.,.]% (!is.na(theta) & !m$etamap$offsettheta) <- real.cov
-  hess %[.,.]% (!is.na(theta) & !m$etamap$offsettheta) <-
+  covar %[.,.]% (!is.NA(theta) & !m$etamap$offsettheta) <- real.cov
+  hess %[.,.]% (!is.NA(theta) & !m$etamap$offsettheta) <-
     EVL3(real.cov, -sginv(., tol = .Machine$double.eps^(3 / 4)), 0)
 
   iteration <-  mplefit$iter 
